      // This is your test publishable API key.
const stripe = Stripe(publickey);

// The items the customer wants to buy
const items = [{ id: "xl-tshirt" }];

let elements;

initialize();
checkStatus();

document
  .querySelector("#payment-form")
  .addEventListener("submit", handleSubmit);

  /* --------------------------------------------------------------------------------------- */
// Fetches a payment intent and captures the client secret
async function initialize() {
  const { clientSecret } = await fetch(url_create_stripe, {
    method: "POST",
    headers: { "Content-Type": "application/json" },
    body: JSON.stringify({ items }),
  }).then((r) => r.json());

  if (!clientSecret) {
    return;
  }

  elements = stripe.elements({ clientSecret });

  const paymentElement = elements.create("payment");
  paymentElement.mount("#payment-element");

  document.querySelector("#loader-info").classList.add("d-none");
}
/* --------------------------------------------------------------------------------------- */


/* -----------------------------------------SUBMIT---------------------------------------------- */
async function handleSubmit(e) {
  e.preventDefault();
  setLoading(true); 

  const {error} = await stripe.confirmSetup({
    elements,
    confirmParams: {
      return_url: return_url,
    },
  });
  if (error.type === "card_error" || error.type === "validation_error") {
    showMessage(error.message);
  } else {
    showMessage("Ocurrió un error inesperado.");
  }
  setLoading(false);
}
/* -------------------------------------------END SUBMIT-------------------------------------------- */

// Retrieve the "setup_intent_client_secret" query parameter appended to
// your return_url by Stripe.js
async function checkStatus() {
  const clientSecret = new URLSearchParams(window.location.search).get(
    "setup_intent_client_secret"
  );

  if (!clientSecret) {
    return;
  }
  
// Retrieve the SetupIntent
stripe.retrieveSetupIntent(clientSecret).then(({setupIntent}) => {
  //console.log('setupIntent',setupIntent)
    switch (setupIntent.status) {
      case 'succeeded': {
        savePaymentMethod(setupIntent.payment_method, clientSecret)
        break;
      }

      case 'processing': {
        showMessage("Completando...");
        break;
      }

      case 'requires_payment_method': {
        showMessage('Ocurrió un error.');
        break;
      }
    }
  });
}

async function savePaymentMethod(paymentMethod, clientSecret) {
    const { statusSave } = await fetch(url_save_paymethod, {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify({ payment_method: paymentMethod, client_secret: clientSecret }),
    }).then((r) => r.json());

    if(statusSave){
      window.location=next_page;
    }
}

// ------- UI helpers -------

function showMessage(messageText) {
  const messageContainer = document.querySelector("#payment-message");

  messageContainer.classList.remove("hidden");
  messageContainer.textContent = messageText;

  setTimeout(function () {
    messageContainer.classList.add("hidden");
    messageText.textContent = "";
  }, 4000);
}

// Show a spinner on payment submission
function setLoading(isLoading) {
  if (isLoading) {
    // Disable the button and show a spinner
    document.querySelector("#submit").disabled = true;
    document.querySelector("#submit").classList.add("d-none");
    document.querySelector("#loader-button").classList.remove("d-none");
  } else {
    document.querySelector("#submit").disabled = false;
    document.querySelector("#submit").classList.remove("d-none");
    document.querySelector("#loader-button").classList.add("d-none");
  }
}